==> sdd.getnetapi-0.1.1-sources.jar: ar/com/sdd/getnetapi/model/Detail.java <==
package ar.com.sdd.getnetapi.model;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;

import java.io.Serializable;
import java.util.Objects;

@SuppressWarnings("unused")
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown = true)
public class Detail implements Serializable {

    @JsonProperty("property")
    private String property;

    @JsonProperty("constraint")
    private String constraint;

    public String getProperty() {
        return property;
    }

    public void setProperty(String property) {
        this.property = property;
    }

    public String getConstraint() {
        return constraint;
    }

    public void setConstraint(String constraint) {
        this.constraint = constraint;
    }

    @Override
    public String toString() {
        return "Detail [" +
                ((property != null) ? "property='" + property + "', " : "") +
                ((constraint != null) ? "constraint='" + constraint + "', " : "") +
                "]";
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        Detail detail = (Detail) o;
        return Objects.equals(property, detail.property) && Objects.equals(constraint, detail.constraint);
    }

    @Override
    public int hashCode() {
        return Objects.hash(property, constraint);
    }
}

==> sdd.getnetapi-0.1.8-sources.jar: ar/com/sdd/getnetapi/model/Detail.java <==
package ar.com.sdd.getnetapi.model;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;

import java.io.Serializable;
import java.util.Objects;

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown = true)
public class Detail implements Serializable {

    @JsonProperty("property")
    private String property;

    @JsonProperty("constraint")
    private Constraint constraint;

    public String getProperty() {
        return property;
    }

    public void setProperty(String property) {
        this.property = property;
    }

    public Constraint getConstraint() {
        return constraint;
    }

    public void setConstraint(Constraint constraint) {
        this.constraint = constraint;
    }

    @Override
    public String toString() {
        return "Detail [" +
                ((property != null) ? "property='" + property + "', " : "") +
                ((constraint != null) ? "constraint='" + constraint + "', " : "") +
                "]";
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        Detail detail = (Detail) o;
        return Objects.equals(property, detail.property) && Objects.equals(constraint, detail.constraint);
    }

    @Override
    public int hashCode() {
        return Objects.hash(property, constraint);
    }
}
